
# RCSid:
#	$Id: isposix-shell.sh,v 1.10 2024/12/04 01:49:29 sjg Exp $
#
#	@(#) Copyright (c) 2021 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

_isPOSIX_SHELL_SH=:

if test -z "$_HAVE_SH"; then
    _HAVE_SH=:

    ##
    # have that does not rely on return code of type
    #
    have() {
        case `(type "$1") 2>&1` in
        *" found") return 1;;
        esac
        return 0
    }
fi

##
# test if we have local
#
# 'local' is not actually part of POSIX
# though most POSIX shells support it,
# some via 'alias local=typeset'
# 
# Since 'alias' is not available on old shells
# we set _local as a variable and you have to eval $_local
# We also set local=$_local for backwards compatability.
#
if have local; then
    _local=local
elif have alias && have typeset; then
    alias local=typeset
    _local=local
else
    _local=:
fi
# for backwards compatability
local=$_local

##
# set isPOSIX_SHELL
#
# Some features of the POSIX shell are very useful.
# We need to be able to know if we can use them.
#
# We set isPOSIX_SHELL={true,false}
# so we can use 'if $isPOSIX_SHELL; then'
# 
if (echo ${PATH%:*}) > /dev/null 2>&1; then
    # true should be a builtin, : certainly is
    isPOSIX_SHELL=:
    # reduce the cost of these
    basename() {
        eval $_local b
        b=${1%$2}
        echo ${b##*/}
    }
    dirname() {
        case "$1" in
        *?/*) echo ${1%/*};;
        /*) echo /;;
        *) echo .;;
        esac
    }
else
    isPOSIX_SHELL=false
    false() {
        return 1
    }
fi

is_posix_shell() {
    $isPOSIX_SHELL
    return
}
